from flask_login import UserMixin
from datetime import datetime
from .. import db

class User(db.Model, UserMixin):
    __tablename__ = 'users'

    id = db.Column(db.Integer, primary_key=True)
    email = db.Column(db.String(120), unique=True, nullable=False)
    password_hash = db.Column(db.String(128), nullable=False)
    role = db.Column(db.String(50), default='user')
    is_verified = db.Column(db.Boolean, default=False)
    excluded_from_analytics = db.Column(db.Boolean, default=False)
    created_at = db.Column(db.DateTime, default=datetime.utcnow)

    # Optional: relationship to submissions
    submissions = db.relationship('Submission', backref='user', lazy=True)


class Submission(db.Model):
    __tablename__ = 'submission'

    id = db.Column(db.Integer, primary_key=True)
    user_id = db.Column(
        db.Integer,
        db.ForeignKey('users.id', name='fk_submission_user_id'),
        nullable=False
    )
    common_name = db.Column(db.String(120), nullable=False)
    scientific_name = db.Column(db.String(120))
    price = db.Column(db.Float, nullable=False)
    source = db.Column(db.String(120))
    timestamp = db.Column(db.DateTime, default=datetime.utcnow)
    height = db.Column(db.Float)
    width = db.Column(db.Float)
    leaf_count = db.Column(db.Integer)
    potting_mix = db.Column(db.String(255))
    container_size = db.Column(db.String(120))
    health_status = db.Column(db.String(50))
    notes = db.Column(db.Text)
    plant_id = db.Column(db.Integer)
    images = db.relationship('SubmissionImage', backref='submission', lazy=True)


class SubmissionImage(db.Model):
    __tablename__ = 'submission_images'

    id = db.Column(db.Integer, primary_key=True)
    submission_id = db.Column(db.Integer, db.ForeignKey('submission.id'), nullable=False)
    file_path = db.Column(db.String(255), nullable=False)
